@@ -1,6 +1,6 @@
 /* papersize.cpp: paper size info
 
-   Copyright (C) 1996-2020 Christian Schenk
+   Copyright (C) 1996-2021 Christian Schenk
 
    This file is part of the MiKTeX Core Library.
 
@@ -36,6 +36,7 @@
 
 using namespace std;
 
+using namespace MiKTeX::Configuration;
 using namespace MiKTeX::Core;
 using namespace MiKTeX::Util;
 
@@ -108,11 +109,11 @@ MIKTEXSTATICFUNC(int) CalculatePostScriptPoints(double value, const string& unit
 
 MIKTEXSTATICFUNC(bool) ChopFloat(char*& lpsz, double& ret)
 {
-  SkipSpace(lpsz);
+  SkipWhitespaceAscii(lpsz);
   bool gotDot = false;
   char* lpszStart = lpsz;
   string str;
-  while (*lpsz != 0 && (IsDigit(*lpsz) || (*lpsz == '.' && !gotDot)))
+  while (*lpsz != 0 && (IsDecimalDigitAscii(*lpsz) || (*lpsz == '.' && !gotDot)))
   {
     str += *lpsz;
     if (*lpsz == '.')
@@ -132,10 +133,10 @@ MIKTEXSTATICFUNC(bool) ChopFloat(char*& lpsz, double& ret)
 
 MIKTEXSTATICFUNC(bool) ChopToken(char*& lpsz, string& ret)
 {
-  SkipSpace(lpsz);
+  SkipWhitespaceAscii(lpsz);
   char* lpszStart = lpsz;
   ret = "";
-  while (*lpsz != 0 && !IsSpace(*lpsz) && *lpsz != ',')
+  while (*lpsz != 0 && !IsWhitespaceAscii(*lpsz) && *lpsz != ',')
   {
     ret += *lpsz;
     *lpsz = 0;
@@ -181,7 +182,7 @@ void SessionImpl::ReadDvipsPaperSizes()
         }
         CharBuffer<char> buf(line.c_str() + 1);
         char* lpsz = buf.GetData();
-        SkipSpace(lpsz);
+        SkipWhitespaceAscii(lpsz);
         if (*lpsz == 0)
         {
           dvipsPaperSizes.clear();
