@@ -1,6 +1,6 @@
 /* texmfroot.cpp: managing TEXMF root directories
 
-   Copyright (C) 1996-2020 Christian Schenk
+   Copyright (C) 1996-2021 Christian Schenk
 
    This file is part of the MiKTeX Core Library.
 
@@ -26,7 +26,7 @@
 #include <fmt/format.h>
 #include <fmt/ostream.h>
 
-#include <miktex/Core/ConfigNames>
+#include <miktex/Configuration/ConfigNames>
 #include <miktex/Core/Environment>
 #include <miktex/Core/Paths>
 #include <miktex/Core/RootDirectoryInfo>
@@ -44,6 +44,7 @@
 
 using namespace std;
 
+using namespace MiKTeX::Configuration;
 using namespace MiKTeX::Core;
 using namespace MiKTeX::Trace;
 using namespace MiKTeX::Util;
@@ -404,11 +405,11 @@ void SessionImpl::ReregisterRootDirectories(const string& roots, bool other)
       MIKTEX_UNEXPECTED();
     }
     ConnectToServer();
-    HResult hr = localServer.pSession->RegisterRootDirectories(_bstr_t(roots.c_str()));
+    HResult hr = localServer->pSession->RegisterRootDirectories(_bstr_t(roots.c_str()));
     if (hr.Failed())
     {
       MiKTeXSessionLib::ErrorInfo errorInfo;
-      HResult hr2 = localServer.pSession->GetErrorInfo(&errorInfo);
+      HResult hr2 = localServer->pSession->GetErrorInfo(&errorInfo);
       if (hr2.Failed())
       {
         MIKTEX_FATAL_ERROR_2(T_("sessionsvc failed for some reason."), "hr", hr.GetText());
