@@ -1,6 +1,6 @@
 /* winSetupService.cpp:
 
-   Copyright (C) 2014-2020 Christian Schenk
+   Copyright (C) 2014-2021 Christian Schenk
 
    This file is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published
@@ -17,6 +17,11 @@
    Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307,
    USA. */
 
+#include "config.h"
+
+#include <miktex/Core/win/COMInitializer>
+#include <miktex/Core/win/HResult>
+
 #include "internal.h"
 
 #include "winSetupService.h"
@@ -25,9 +30,11 @@
 
 using namespace std;
 
+using namespace MiKTeX::Configuration;
 using namespace MiKTeX::Core;
 using namespace MiKTeX::Packages;
 using namespace MiKTeX::Setup;
+using namespace MiKTeX::Trace;
 using namespace MiKTeX::Util;
 
 PathName SetupService::GetDefaultCommonInstallDir()
@@ -61,14 +68,6 @@ PathName SetupService::GetDefaultPortableRoot()
   return PathName("C:/miktex-portable");
 }
 
-winSetupServiceImpl::winSetupServiceImpl()
-{
-  if (FAILED(CoInitialize(nullptr)))
-  {
-    MIKTEX_FATAL_ERROR(T_("COM could not be initialized"));
-  }
-}
-
 void winSetupServiceImpl::Initialize()
 {
   SetupServiceImpl::Initialize();
@@ -130,28 +129,27 @@ constexpr auto LD_IFCOMMON = 0x00000040;
 #define EXEPATH(name) fmt::format("%MIKTEX_INSTALL%\\{0}\\{1}", MIKTEX_PATH_BIN_DIR, name)
 #define DOCPATH(name) fmt::format("%MIKTEX_INSTALL%\\{0}\\{1}", MIKTEX_PATH_MIKTEX_DOC_DIR, name)
 
-BEGIN_ANONYMOUS_NAMESPACE;
+vector<ShellLinkData> winSetupServiceImpl::GetShellLinks()
+{
+  return vector<ShellLinkData> {
+    // "MiKTeX Console"
+    {
+      false,
+        false,
+        "",
+        "MiKTeX Console",
+        EXEPATH(MIKTEX_CONSOLE_EXE),
+        LD_USESHOWCMD | LD_USEDESC,
+        T_("MiKTeX Console helps you to manage your MiKTeX configuration."),
+        "",
+        "",
+        0,
+        "",
+        SW_SHOWNORMAL,
+        0,
+    },
 
-const ShellLinkData shellLinks[] = {
-
-  // "MiKTeX Console"
-  {
-    false,
-    false,
-    "",
-    "MiKTeX Console",
-    EXEPATH(MIKTEX_CONSOLE_EXE),
-    LD_USESHOWCMD | LD_USEDESC,
-    T_("The MiKTeX Console helps you to manage the MiKTeX configuration."),
-    "",
-    "",
-    0,
-    "",
-    SW_SHOWNORMAL,
-    0,
-  },
-
-  // "TeXworks"
+      // "TeXworks"
   {
     false,
     false,
@@ -159,7 +157,7 @@ const ShellLinkData shellLinks[] = {
     "TeXworks",
     EXEPATH(MIKTEX_TEXWORKS_EXE),
     LD_USESHOWCMD | LD_USEDESC,
-    T_("TeXworks is a simple TeX front-end program."),
+    T_("TeXworks is a TeX front-end program."),
     "",
     "",
     0,
@@ -289,125 +287,125 @@ const ShellLinkData shellLinks[] = {
 
 #if 0
   // "Help->Manual"
-  {
-    false,
-    true,
-    "Help",
-    "MiKTeX Manual",
-    DOCPATH(MIKTEX_MAIN_HELP_FILE),
-    LD_USESHOWCMD,
-    "",
-    "",
-    "",
-    0,
-    "",
-    SW_SHOWNORMAL,
-    0,
-  },
+      {
+        false,
+        true,
+        "Help",
+        "MiKTeX Manual",
+        DOCPATH(MIKTEX_MAIN_HELP_FILE),
+        LD_USESHOWCMD,
+        "",
+        "",
+        "",
+        0,
+        "",
+        SW_SHOWNORMAL,
+        0,
+      },
 #endif
 
 #if 0
-  // "Help->FAQ"
-  {
-    false,
-    true,
-    "Help",
-    "MiKTeX FAQ",
-    DOCPATH(MIKTEX_FAQ_HELP_FILE),
-    LD_USESHOWCMD,
-    "",
-    "",
-    "",
-    0,
-    "",
-    SW_SHOWNORMAL,
-    0,
-  },
+      // "Help->FAQ"
+      {
+        false,
+        true,
+        "Help",
+        "MiKTeX FAQ",
+        DOCPATH(MIKTEX_FAQ_HELP_FILE),
+        LD_USESHOWCMD,
+        "",
+        "",
+        "",
+        0,
+        "",
+        SW_SHOWNORMAL,
+        0,
+      },
 #endif
 
 #if 0
-  // "MiKTeX on the Web->MiKTeX Project Page"
-  {
-    true,
-    true,
-    "MiKTeX on the Web",
-    "MiKTeX Project Page",
-    MIKTEX_URL_WWW,
-    0,
-    "",
-    "",
-    "",
-    0,
-    "",
-    0,
-    0,
-  },
+      // "MiKTeX on the Web->MiKTeX Project Page"
+      {
+        true,
+        true,
+        "MiKTeX on the Web",
+        "MiKTeX Project Page",
+        MIKTEX_URL_WWW,
+        0,
+        "",
+        "",
+        "",
+        0,
+        "",
+        0,
+        0,
+      },
 #endif
 
 #if 0
-  // "MiKTeX on the Web->Support"
-  {
-    true,
-    true,
-    "MiKTeX on the Web",
-    "MiKTeX Support",
-    MIKTEX_URL_WWW_SUPPORT,
-    0,
-    "",
-    "",
-    "",
-    0,
-    "",
-    0,
-    0,
-  },
+      // "MiKTeX on the Web->Support"
+      {
+        true,
+        true,
+        "MiKTeX on the Web",
+        "MiKTeX Support",
+        MIKTEX_URL_WWW_SUPPORT,
+        0,
+        "",
+        "",
+        "",
+        0,
+        "",
+        0,
+        0,
+      },
 #endif
 
 #if 0
-  // "MiKTeX on the Web->Give back"
-  {
-    true,
-    true,
-    "MiKTeX on the Web",
-    "Give back",
-    MIKTEX_URL_WWW_GIVE_BACK,
-    0,
-    "",
-    "",
-    "",
-    0,
-    "",
-    0,
-    0,
-  },
+      // "MiKTeX on the Web->Give back"
+      {
+        true,
+        true,
+        "MiKTeX on the Web",
+        "Give back",
+        MIKTEX_URL_WWW_GIVE_BACK,
+        0,
+        "",
+        "",
+        "",
+        0,
+        "",
+        0,
+        0,
+      },
 #endif
 
 #if 0
-  // "MiKTeX on the Web->Known Issues"
-  {
-    true,
-    true,
-    "MiKTeX on the Web",
-    "Known Issues",
-    MIKTEX_URL_WWW_KNOWN_ISSUES,
-    0,
-    "",
-    "",
-    "",
-    0,
-    "",
-    0,
-    0,
-  },
+      // "MiKTeX on the Web->Known Issues"
+      {
+        true,
+        true,
+        "MiKTeX on the Web",
+        "Known Issues",
+        MIKTEX_URL_WWW_KNOWN_ISSUES,
+        0,
+        "",
+        "",
+        "",
+        0,
+        "",
+        0,
+        0,
+      },
 #endif
-};
-
-END_ANONYMOUS_NAMESPACE;
+  };
+}
 
 void winSetupServiceImpl::CreateProgramIcons()
 {
+  COMInitializer comInitializer;
   PathName path = CreateProgramFolder();
-  for (const ShellLinkData& shlnk : shellLinks)
+  for (const ShellLinkData& shlnk : GetShellLinks())
   {
     CreateShellLink(path, shlnk);
   }
@@ -444,7 +442,7 @@ void winSetupServiceImpl::CreateShellLink(const PathName& pathFolder, const Shel
 
   if (File::Exists(pathLink))
   {
-    Log(fmt::format(T_("removing {}...\n"), Q_(pathLink)));
+    LogInternal(TraceLevel::Info, fmt::format("removing {}...\n", Q_(pathLink)));
     if (!options.IsDryRun)
     {
       File::Delete(pathLink);
@@ -462,11 +460,11 @@ void winSetupServiceImpl::CreateShellLink(const PathName& pathFolder, const Shel
 
   if (ld.isUrl)
   {
-    Log(fmt::format(T_("creating internet shortcut {}...\n"), Q_(pathLink)));
+    LogInternal(TraceLevel::Info, fmt::format("creating internet shortcut {}...\n", Q_(pathLink)));
   }
   else
   {
-    Log(fmt::format(T_("creating shell link {}...\n"), Q_(pathLink)));
+    LogInternal(TraceLevel::Info, fmt::format("creating shell link {}...\n", Q_(pathLink)));
   }
 
   if (options.IsDryRun)
@@ -484,11 +482,11 @@ void winSetupServiceImpl::CreateShellLink(const PathName& pathFolder, const Shel
 
     IShellLinkWPtr psl;
 
-    HRESULT hr = CoCreateInstance(CLSID_ShellLink, 0, CLSCTX_INPROC_SERVER, IID_IShellLinkW, reinterpret_cast<void**>(&psl));
+    HResult hr = CoCreateInstance(CLSID_ShellLink, 0, CLSCTX_INPROC_SERVER, IID_IShellLinkW, reinterpret_cast<void**>(&psl));
 
-    if (FAILED(hr))
+    if (hr.Failed())
     {
-      Log(fmt::format(T_("IShellLinkW could not be created ({0:#08X})\n"), hr));
+      LogInternal(TraceLevel::Error, fmt::format("IShellLinkW could not be created (hr={0})\n", hr));
       MIKTEX_UNEXPECTED();
     }
 
@@ -496,18 +494,18 @@ void winSetupServiceImpl::CreateShellLink(const PathName& pathFolder, const Shel
 
     hr = psl->SetPath(Expand(ld.pathName, str).c_str());
 
-    if (FAILED(hr))
+    if (hr.Failed())
     {
-      Log(fmt::format(T_("IShellLinkW::SetPath() failed ({0:#08X})\n"), hr));
+      LogInternal(TraceLevel::Error, fmt::format("IShellLinkW::SetPath() failed (hr={0})\n", hr));
       MIKTEX_UNEXPECTED();
     }
 
     if ((ld.flags & LD_USEARGS) != 0)
     {
       hr = psl->SetArguments(Expand(ld.args, str).c_str());
-      if (FAILED(hr))
+      if (hr.Failed())
       {
-        Log(fmt::format(T_("IShellLinkW::SetArguments() failed ({0:#08X})\n"), hr));
+        LogInternal(TraceLevel::Error, fmt::format("IShellLinkW::SetArguments() failed (hr={0})\n", hr));
         MIKTEX_UNEXPECTED();
       }
     }
@@ -515,9 +513,9 @@ void winSetupServiceImpl::CreateShellLink(const PathName& pathFolder, const Shel
     if ((ld.flags & LD_USEDESC) != 0)
     {
       hr = psl->SetDescription(UW_(ld.description));
-      if (FAILED(hr))
+      if (hr.Failed())
       {
-        Log(fmt::format(T_("IShellLinkW::SetDescription() failed ({0:#08X})\n"), hr));
+        LogInternal(TraceLevel::Error, fmt::format("IShellLinkW::SetDescription() failed (hr={0})\n", hr));
         MIKTEX_UNEXPECTED();
       }
     }
@@ -525,9 +523,9 @@ void winSetupServiceImpl::CreateShellLink(const PathName& pathFolder, const Shel
     if ((ld.flags & LD_USEICON) != 0)
     {
       hr = psl->SetIconLocation(Expand(ld.iconPath, str).c_str(), ld.iconIndex);
-      if (FAILED(hr))
+      if (hr.Failed())
       {
-        Log(fmt::format(T_("IShellLinkW::SetIconLocation() failed ({0:#08X})\n"), hr));
+        LogInternal(TraceLevel::Error, fmt::format("IShellLinkW::SetIconLocation() failed (hr={0})\n", hr));
         MIKTEX_UNEXPECTED();
       }
     }
@@ -535,9 +533,9 @@ void winSetupServiceImpl::CreateShellLink(const PathName& pathFolder, const Shel
     if ((ld.flags & LD_USEWORKDIR) != 0)
     {
       hr = psl->SetWorkingDirectory(Expand(ld.workingDir, str).c_str());
-      if (FAILED(hr))
+      if (hr.Failed())
       {
-        Log(fmt::format(T_("IShellLinkW::SetWorkingDirectory() failed ({0:#08X})\n"), hr));
+        LogInternal(TraceLevel::Error, fmt::format("IShellLinkW::SetWorkingDirectory() failed (hr={0})\n", hr));
         MIKTEX_UNEXPECTED();
       }
     }
@@ -545,9 +543,9 @@ void winSetupServiceImpl::CreateShellLink(const PathName& pathFolder, const Shel
     if ((ld.flags & LD_USESHOWCMD) != 0)
     {
       hr = psl->SetShowCmd(ld.showCmd);
-      if (FAILED(hr))
+      if (hr.Failed())
       {
-        Log(fmt::format(T_("IShellLinkW::SetShowCmd() failed ({0:#08X})\n"), hr));
+        LogInternal(TraceLevel::Error, fmt::format("IShellLinkW::SetShowCmd() failed (hr={0})\n", hr));
         MIKTEX_UNEXPECTED();
       }
     }
@@ -555,9 +553,9 @@ void winSetupServiceImpl::CreateShellLink(const PathName& pathFolder, const Shel
     if ((ld.flags & LD_USEHOTKEY) != 0)
     {
       hr = psl->SetHotkey(ld.hotKey);
-      if (FAILED(hr))
+      if (hr.Failed())
       {
-        Log(fmt::format(T_("IShellLinkW::SetHotkey() failed ({0:#08X})\n"), hr));
+        LogInternal(TraceLevel::Error, fmt::format("IShellLinkW::SetHotkey() failed (hr={0})\n", hr));
         MIKTEX_UNEXPECTED();
       }
     }
@@ -566,17 +564,17 @@ void winSetupServiceImpl::CreateShellLink(const PathName& pathFolder, const Shel
 
     hr = psl->QueryInterface(IID_IPersistFile, reinterpret_cast<void**>(&ppf));
 
-    if (FAILED(hr))
+    if (hr.Failed())
     {
-      Log(fmt::format(T_("IPersistFile could not be created ({0:#08X})\n"), hr));
+      LogInternal(TraceLevel::Error, fmt::format("IPersistFile could not be created (hr={0})\n", hr));
       MIKTEX_UNEXPECTED();
     }
 
     hr = ppf->Save(pathLink.ToWideCharString().c_str(), TRUE);
 
-    if (FAILED(hr))
+    if (hr.Failed())
     {
-      Log(fmt::format(T_("IPersistFile::Save() failed ({0:#08X})\n"), hr));
+      LogInternal(TraceLevel::Error, fmt::format("IPersistFile::Save() failed (hr={0})\n", hr));
       MIKTEX_UNEXPECTED();
     }
   }
@@ -590,19 +588,19 @@ void winSetupServiceImpl::CreateInternetShortcut(const PathName& path, const str
 
   IUniformResourceLocatorWPtr pURL;
 
-  HRESULT hr = CoCreateInstance(CLSID_InternetShortcut, 0, CLSCTX_INPROC_SERVER, IID_IUniformResourceLocatorW, reinterpret_cast<void**>(&pURL));
+  HResult hr = CoCreateInstance(CLSID_InternetShortcut, 0, CLSCTX_INPROC_SERVER, IID_IUniformResourceLocatorW, reinterpret_cast<void**>(&pURL));
 
-  if (FAILED(hr))
+  if (hr.Failed())
   {
-    Log(fmt::format(T_("IUniformResourceLocator could not be created ({0:#08X})\n"), hr));
+    LogInternal(TraceLevel::Error, fmt::format("IUniformResourceLocator could not be created (hr={0})\n", hr));
     MIKTEX_UNEXPECTED();
   }
 
   hr = pURL->SetURL(UW_(url), 0);
 
-  if (FAILED(hr))
+  if (hr.Failed())
   {
-    Log(fmt::format(T_("IUniformResourceLocatorW::SetURL() failed ({0:#08X})\n"), hr));
+    LogInternal(TraceLevel::Error, fmt::format("IUniformResourceLocatorW::SetURL() failed (hr={0})\n", hr));
     MIKTEX_UNEXPECTED();
   }
 
@@ -610,17 +608,17 @@ void winSetupServiceImpl::CreateInternetShortcut(const PathName& path, const str
 
   hr = pURL->QueryInterface(IID_IPersistFile, reinterpret_cast<void**>(&pPF));
 
-  if (FAILED(hr))
+  if (hr.Failed())
   {
-    Log(fmt::format(T_("IPersistFile could not be created ({0:#08X})\n"), hr));
+    LogInternal(TraceLevel::Error, fmt::format("IPersistFile could not be created (hr={0})\n", hr));
     MIKTEX_UNEXPECTED();
   }
 
   hr = pPF->Save(path.ToWideCharString().c_str(), TRUE);
 
-  if (FAILED(hr))
+  if (hr.Failed())
   {
-    Log(fmt::format(T_("IPersistFile::Save() failed ({0:#08X})\n"), hr));
+    LogInternal(TraceLevel::Error, fmt::format("IPersistFile::Save() failed (hr={0})\n", hr));
     MIKTEX_UNEXPECTED();
   }
 }
@@ -634,7 +632,6 @@ constexpr auto UNINST_DISPLAY_VERSION = MIKTEX_DISPLAY_VERSION_STR;
    : UNINST_DISPLAY_NAME)
 constexpr auto UNINST_ABOUT_URL = "https://miktex.org/about";
 constexpr auto UNINST_UPDATE_URL = "https://miktex.org";
-constexpr auto UNINST_COMMENTS = T_("MiKTeX is a scalable TeX distribution for Windows, Linux and macOS.");
 constexpr auto UNINST_README = UNINST_HELP_LINK;
 
 constexpr auto UNINST_DISPLAY_NAME = MIKTEX_PRODUCTNAME_STR;
@@ -673,7 +670,7 @@ void winSetupServiceImpl::RegisterUninstaller()
 
   // set values
   PathName installRoot(GetInstallRoot());
-  AddUninstallerRegValue(hkey, "Comments", UNINST_COMMENTS);
+  AddUninstallerRegValue(hkey, "Comments", T_("MiKTeX is a scalable TeX distribution for Windows, Linux and macOS."));
   AddUninstallerRegValue(hkey, "DisplayIcon", iconPath.ToString());
   AddUninstallerRegValue(hkey, "DisplayName", UNINST_DISPLAY_STRING);
   AddUninstallerRegValue(hkey, "DisplayVersion", UNINST_DISPLAY_VERSION);
