@@ -1,6 +1,6 @@
 /* miktex/TeXAndFriends/WebApp.h:                       -*- C++ -*-
 
-   Copyright (C) 1996-2020 Christian Schenk
+   Copyright (C) 1996-2021 Christian Schenk
 
    This file is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published
@@ -35,8 +35,8 @@
 
 #include <miktex/Core/Exceptions>
 #include <miktex/Core/FileType>
-#include <miktex/Core/OptionSet>
-#include <miktex/Core/PathName>
+#include <miktex/Util/OptionSet>
+#include <miktex/Util/PathName>
 #include <miktex/Core/Utils>
 
 #include <miktex/Util/StringUtil>
@@ -77,22 +77,22 @@ enum class Feature
 
 template<class FileType> inline bool miktexopentfmfile(FileType& f, const char* fileName)
 {
-  return OpenTFMFile(&f, MiKTeX::Core::PathName(fileName));
+  return OpenTFMFile(&f, MiKTeX::Util::PathName(fileName));
 }
 
 template<class FileType> inline bool miktexopenvffile(FileType& f, const char* fileName)
 {
-  return OpenVFFile(&f, MiKTeX::Core::PathName(fileName));
+  return OpenVFFile(&f, MiKTeX::Util::PathName(fileName));
 }
 
 template<class FileType> inline int miktexopenxfmfile(FileType& f, const char* fileName)
 {
-  return OpenXFMFile(&f, MiKTeX::Core::PathName(fileName));
+  return OpenXFMFile(&f, MiKTeX::Util::PathName(fileName));
 }
 
 template<class FileType> inline bool miktexopenxvffile(FileType& f, const char* fileName)
 {
-  return OpenXVFFile(&f, MiKTeX::Core::PathName(fileName));
+  return OpenXVFFile(&f, MiKTeX::Util::PathName(fileName));
 }
 
 template<class FileType> inline void miktexprintmiktexbanner(FileType& f)
@@ -146,6 +146,9 @@ public:
 public:
   MIKTEXMFTHISAPI(bool) AmI(const std::string& name) const;
 
+protected:
+  MIKTEXMFTHISAPI(std::string) Translate(const char* msgId);
+
 protected:
   virtual MIKTEXMFTHISAPI(void) AddOptions();
 
@@ -158,11 +161,10 @@ protected:
 protected:
   MIKTEXMFTHISAPI(void) AddOption(const std::string& name, const std::string& help, int opt, int argInfo = POPT_ARG_NONE, const std::string& argDescription = "", void* arg = nullptr, char shortName = 0);
 
-  // DEPRECATED
 protected:
-  void AddOption(const char* nameAndHelp, int opt, int argInfo = POPT_ARG_NONE, const std::string& argDescription = "", void * arg = nullptr, char shortName = 0)
+  void AddOption(const std::string& name, int opt, int argInfo = POPT_ARG_NONE, const std::string& argDescription = "", void * arg = nullptr, char shortName = 0)
   {
-    AddOption(nameAndHelp, nameAndHelp + strlen(nameAndHelp) + 1, opt, argInfo, argDescription, arg, shortName);
+    AddOption(name, "", opt, argInfo, argDescription, arg, shortName);
   }
 
 protected:
@@ -188,7 +190,7 @@ protected:
   MIKTEXMFTHISAPI(void) ShowHelp(bool usageOnly = false) const;
 
 protected:
-  MIKTEXMFTHISAPI(void) BadUsage() const;
+  MIKTEXMFTHISAPI(void) BadUsage();
 
 protected:
   virtual std::string GetUsage() const
@@ -226,10 +228,10 @@ public:
   MIKTEXMFTHISAPI(bool) AmIMETAFONT() const;
 
 public:
-  MIKTEXMFTHISAPI(MiKTeX::Core::PathName) GetTcxFileName() const;
+  MIKTEXMFTHISAPI(MiKTeX::Util::PathName) GetTcxFileName() const;
 
 protected:
-  MIKTEXMFTHISAPI(void) SetTcxFileName(const MiKTeX::Core::PathName& tcxFileName);
+  MIKTEXMFTHISAPI(void) SetTcxFileName(const MiKTeX::Util::PathName& tcxFileName);
 
 protected:
   MIKTEXMFTHISAPI(void) Enable8BitChars(bool enable8BitChars);
@@ -324,14 +326,14 @@ public:
     }
     catch (const MiKTeX::Core::MiKTeXException& ex)
     {
-      MiKTeX::App::Application::Sorry(argv[0], ex);
+      app.Sorry(argv[0], ex);
       app.Finalize2(1);
       ex.Save();
       return 1;
     }
     catch (const std::exception& ex)
     {
-      MiKTeX::App::Application::Sorry(argv[0], ex);
+      app.Sorry(argv[0], ex);
       app.Finalize2(1);
       return 1;
     }
