@@ -47,10 +47,7 @@
 #endif
 #define STRINGIFY_2(s) #s
 #define STRINGIFY(s) STRINGIFY_2(s)
-#if defined(MIKTEX)
-#undef TW_BUILD_ID
-#define TW_BUILD_ID_STR MIKTEX_BANNER_STR
-#else
+#if !defined(MIKTEX)
 #define TW_BUILD_ID_STR STRINGIFY(TW_BUILD_ID)
 #endif
 
