@@ -1,6 +1,6 @@
 /* main.cpp:
 
-   Copyright (C) 2017-2020 Christian Schenk
+   Copyright (C) 2017-2021 Christian Schenk
 
    This file is part of MiKTeX Console.
 
@@ -30,6 +30,7 @@
 #include <QApplication>
 #include <QtWidgets>
 #include <QSystemTrayIcon>
+#include <QTranslator>
 
 #include <log4cxx/logger.h>
 #include <log4cxx/rollingfileappender.h>
@@ -37,10 +38,12 @@
 
 #include "console-version.h"
 
+#include <miktex/Core/AutoResource>
 #include <miktex/Core/Exceptions>
 #include <miktex/Core/LockFile>
 #include <miktex/Core/Paths>
 #include <miktex/Core/Session>
+#include <miktex/Locale/Translator>
 #include <miktex/UI/Qt/ErrorDialog>
 #include <miktex/Util/StringUtil>
 #include <miktex/Trace/Trace>
@@ -49,7 +52,9 @@
 
 #include "mainwindow.h"
 
+using namespace MiKTeX::Configuration;
 using namespace MiKTeX::Core;
+using namespace MiKTeX::Locale;
 using namespace MiKTeX::Trace;
 using namespace MiKTeX::UI::Qt;
 using namespace MiKTeX::Util;
@@ -207,6 +212,50 @@ PathName GetExecutableDir()
 }
 #endif
 
+vector<unique_ptr<QTranslator>> qTranslators;
+
+void InstallTranslators(shared_ptr<Session> session)
+{
+  auto uiLsystemUiLanguages = Translator("miktex-console", nullptr, session).GetSystemUILanguages();
+  if (uiLsystemUiLanguages.empty())
+  {
+    return;
+  }
+  reverse(uiLsystemUiLanguages.begin(), uiLsystemUiLanguages.end());
+  vector<string> domains{ "ui", "console" };
+  vector<PathName> searchPath{ PathName(":/i18n") };
+  string localeDir;
+  if (session->TryGetConfigValue("Translator", "BaseDir", localeDir))
+  {
+    searchPath.push_back(PathName(localeDir));
+  }
+  for (const auto& uiLang : uiLsystemUiLanguages)
+  {
+    QLocale uiLocale = QLocale(QString::fromStdString(uiLang));
+    for (const auto& domain : domains)
+    {
+      for (const auto& path : searchPath)
+      {
+        auto qTranslator = make_unique<QTranslator>();
+        if (qTranslator->load(uiLocale, QString::fromStdString(domain), "_", QString::fromStdString(path.ToString()), ".qm"))
+        {
+          QCoreApplication::installTranslator(qTranslator.get());
+          qTranslators.push_back(move(qTranslator));
+        }
+      }
+    }
+  }
+}
+
+void RemoveTranslators()
+{
+  for (auto &t : qTranslators)
+  {
+    QCoreApplication::removeTranslator(t.get());
+  }
+  qTranslators.clear();
+}
+
 int main(int argc, char* argv[])
 {
   int ret = 0;
@@ -216,7 +265,6 @@ int main(int argc, char* argv[])
   bool optHide = false;
   bool optMkmaps = false;
   bool optVersion = false;
-  QString displayName = "MiKTeX Console";
 #if defined(MIKTEX_MACOS_BUNDLE)
   PathName plugIns = GetExecutableDir() / PathName("..") / PathName("PlugIns");
   plugIns.MakeFullyQualified();
@@ -226,11 +274,12 @@ int main(int argc, char* argv[])
   QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
 #endif
   QApplication application(argc, argv);
+  QString displayName = TheNameOfTheGame;
 #if QT_VERSION >= 0x050000
   application.setApplicationDisplayName(displayName);
 #endif
   unique_ptr<MiKTeX::Core::LockFile> lockFile;
-  MiKTeX::Core::PathName lockFileName;
+  MiKTeX::Util::PathName lockFileName;
   try
   {
     lockFileName.SetToHomeDirectory();
@@ -238,7 +287,7 @@ int main(int argc, char* argv[])
     lockFile = LockFile::Create(lockFileName);
     if (!lockFile->TryLock(500ms))
     {
-      QMessageBox::warning(nullptr, displayName, "MiKTeX Console is already running.");
+      QMessageBox::warning(nullptr, displayName, QCoreApplication::translate("main", "%1 is already running.").arg(TheNameOfTheGame));
       return 1;
     }
   }
@@ -247,7 +296,7 @@ int main(int argc, char* argv[])
 #if defined(MIKTEX_WINDOWS)
     OutputDebugStringW(StringUtil::UTF8ToWideChar(e.what()).c_str());
 #endif
-    QMessageBox::critical(nullptr, displayName, QString("MiKTeX Console cannot be started.\n\nRemedy: remove %1").arg(QString::fromUtf8(lockFileName.GetData())));
+    QMessageBox::critical(nullptr, displayName, QCoreApplication::translate("main", "%1 cannot be started.\n\nRemedy: remove %2").arg(TheNameOfTheGame).arg(QString::fromUtf8(lockFileName.GetData())));
     return 1;
   }
   MainWindow::Pages startPage = MainWindow::Pages::Overview;
@@ -335,15 +384,17 @@ int main(int argc, char* argv[])
     }
     initInfo.SetProgramInvocationName(argv[0]);
     shared_ptr<Session> session = Session::Create(initInfo);
+    InstallTranslators(session);
+    MIKTEX_AUTO(RemoveTranslators());
     bool switchToAdmin = false;
     if (optAdmin)
     {
       if (!session->RunningAsAdministrator())
       {
 #if defined(MIKTEX_WINDOWS)
-        QMessageBox::critical(nullptr, displayName, "Administrator mode was requested (--admin), but the program is not running elevated (as Administrator).");
+        QMessageBox::critical(nullptr, displayName, QCoreApplication::translate("main", "Administrator mode was requested (--admin), but the program is not running as Administrator."));
 #else
-        QMessageBox::critical(nullptr, displayName, "Administrator mode was requested (--admin), but the program is not running as root user.");
+        QMessageBox::critical(nullptr, displayName, QCoreApplication::translate("main", "Administrator mode was requested (--admin), but the program is not running as root."));
 #endif
         return 1;
       }
@@ -368,12 +419,12 @@ int main(int argc, char* argv[])
       log4cxx::xml::DOMConfigurator::configure(xmlFileName.ToWideCharString());
       isLog4cxxConfigured = true;
       traceSink.FlushPendingTraceMessages();
-      LOG4CXX_INFO(logger, "starting: " << Utils::MakeProgramVersionString("MiKTeX Console", VersionNumber(MIKTEX_COMPONENT_VERSION_STR)));
+      LOG4CXX_INFO(logger, "starting: " << Utils::MakeProgramVersionString(TheNameOfTheGame, VersionNumber(MIKTEX_COMPONENT_VERSION_STR)));
     }
     if (optVersion)
     {
       cout
-        << Utils::MakeProgramVersionString("MiKTeX Console", VersionNumber(MIKTEX_COMPONENT_VERSION_STR)) << endl
+        << Utils::MakeProgramVersionString(TheNameOfTheGame, VersionNumber(MIKTEX_COMPONENT_VERSION_STR)) << endl
 	<< endl
         << MIKTEX_COMP_COPYRIGHT_STR << endl
 	<< endl
@@ -430,7 +481,7 @@ int main(int argc, char* argv[])
     {
       traceSink.FlushPendingTraceMessages();
     }
-    if (QMessageBox::critical(nullptr, "MiKTeX Console", "Sorry, but something went wrong.\n\nDo you want to see the error details?",
+    if (QMessageBox::critical(nullptr, displayName, QCoreApplication::translate("main", "Sorry, but something went wrong.\n\nDo you want to see the error details?"),
       QMessageBox::StandardButtons(QMessageBox::StandardButton::Yes | QMessageBox::StandardButton::No))
       == QMessageBox::StandardButton::Yes)
     {
@@ -449,7 +500,7 @@ int main(int argc, char* argv[])
     {
       traceSink.FlushPendingTraceMessages();
     }
-    if (QMessageBox::critical(nullptr, "MiKTeX Console", "Sorry, but something went wrong.\n\nDo you want to see the error details?",
+    if (QMessageBox::critical(nullptr, displayName, QCoreApplication::translate("main", "Sorry, but something went wrong.\n\nDo you want to see the error details?"),
       QMessageBox::StandardButtons(QMessageBox::StandardButton::Yes | QMessageBox::StandardButton::No))
       == QMessageBox::StandardButton::Yes)
     {
