@@ -1,6 +1,6 @@
 /* epstopdf.cpp: epstopdf
 
-   Copyright (C) 2000-2020 Christian Schenk
+   Copyright (C) 2000-2021 Christian Schenk
    Copyright (C) 1998-2001 by Sebastian Rahtz et al.
 
    This file is part of EPStoPDF.
@@ -49,6 +49,10 @@
 #include <miktex/Util/StringUtil>
 #include <miktex/Wrappers/PoptWrapper>
 
+#if defined(MIKTEX_WINDOWS)
+#include <miktex/Core/win/ConsoleCodePageSwitcher>
+#endif
+
 #include "epstopdf-version.h"
 
 using namespace MiKTeX::App;
@@ -1035,7 +1039,16 @@ void EpsToPdfApp::Run(int argc, const char** argv)
   if (gsProcess != nullptr)
   {
     gsProcess->WaitForExit();
+    if (gsProcess->get_ExitStatus() != ProcessExitStatus::Exited)
+    {
+      FatalError(T_("Ghostscript exited unexpectedly."));
+    }
+    auto gsExitCode = gsProcess->get_ExitCode();
     gsProcess = nullptr;
+    if (gsExitCode != 0)
+    {
+      FatalError(fmt::format(T_("Ghostscript exited with error {0}"), gsExitCode));
+    }
   }
 
   Finalize2(0);
@@ -1051,6 +1064,9 @@ void EpsToPdfApp::Run(int argc, const char** argv)
 
 int MAIN(int argc, MAINCHAR** argv)
 {
+#if defined(MIKTEX_WINDOWS)
+  ConsoleCodePageSwitcher cpSwitcher;
+#endif
   EpsToPdfApp app;
   try
   {
@@ -1075,13 +1091,13 @@ int MAIN(int argc, MAINCHAR** argv)
   }
   catch (const MiKTeXException& e)
   {
-    Application::Sorry(THE_NAME_OF_THE_GAME, e);
+    app.Sorry(THE_NAME_OF_THE_GAME, e);
     e.Save();
     return 1;
   }
   catch (const exception& e)
   {
-    Application::Sorry(THE_NAME_OF_THE_GAME, e);
+    app.Sorry(THE_NAME_OF_THE_GAME, e);
     return 1;
   }
   catch (int exitCode)
