@@ -1,6 +1,6 @@
 /* mthelp.cpp:
 
-   Copyright (C) 2004-2020 Christian Schenk
+   Copyright (C) 2004-2021 Christian Schenk
 
    This file is a part of MTHelp.
 
@@ -29,8 +29,8 @@
 #include "mthelp-version.h"
 
 #include <miktex/App/Application>
+#include <miktex/Configuration/ConfigNames>
 #include <miktex/Core/BufferSizes>
-#include <miktex/Core/ConfigNames>
 #include <miktex/Core/Directory>
 #include <miktex/Core/Exceptions>
 #include <miktex/Core/Paths>
@@ -41,6 +41,10 @@
 #include <miktex/PackageManager/PackageManager>
 #include <miktex/Wrappers/PoptWrapper>
 
+#if defined(MIKTEX_WINDOWS)
+#include <miktex/Core/win/ConsoleCodePageSwitcher>
+#endif
+
 #include <iomanip>
 #include <iostream>
 #include <map>
@@ -51,6 +55,7 @@
 #include <fmt/ostream.h>
 
 using namespace MiKTeX::App;
+using namespace MiKTeX::Configuration;
 using namespace MiKTeX::Core;
 using namespace MiKTeX::Packages;
 using namespace MiKTeX::Util;
@@ -574,6 +579,9 @@ void MiKTeXHelp::Run(int argc, const char** argv)
 
 int MAIN(int argc, MAINCHAR** argv)
 {
+#if defined(MIKTEX_WINDOWS)
+  ConsoleCodePageSwitcher cpSwitcher;
+#endif
   MiKTeXHelp app;
   try
   {
@@ -602,13 +610,13 @@ int MAIN(int argc, MAINCHAR** argv)
   }
   catch (const MiKTeXException& ex)
   {
-    Application::Sorry(TheNameOfTheGame, ex);
+    app.Sorry(TheNameOfTheGame, ex);
     ex.Save();
     return 1;
   }
   catch (const exception& ex)
   {
-    Application::Sorry(TheNameOfTheGame, ex);
+    app.Sorry(TheNameOfTheGame, ex);
     return 1;
   }
   catch (int exitCode)
